==> llm-docs-0.1.4.tgz: package/docs/development/claude-integration.md <==
---
id: development-claude-integration
---
# Claude Integration Guide

<!-- title: Claude Integration Guide -->
<!-- description: Guide for integrating Claude AI with the LLM Platform Platform ecosystem -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide provides comprehensive documentation for integrating Claude AI with the LLM Platform Platform ecosystem. It covers architecture, development standards, security considerations, and best practices for working with Claude in our multi-project environment.

## Ecosystem Architecture

### Core Projects

The LLM Platform AI Platform consists of these interconnected projects:

1. **bfapi**: API Gateway service
2. **llm-mcp**: Model Control Plane
3. **bfllm**: Core LLM services
4. **bfrfp**: Content generation
5. **llm-ui**: Frontend components
6. **llm-gateway-sdk**: Client library
7. **bfdocs**: Documentation hub
8. **llmcli**: CLI for platform management
9. **bfcicomponents**: CI/CD components
10. **llm_platform_recipe**: Drupal integration

### Integration Components

#### Drupal Modules
- **llm-mcp**: AI orchestration and model context protocol
- **llm**: Platform integration
- **ai_swarm_intelligence**: Swarm capabilities
- **secure_drupal**: Security framework
- **Integration modules**: field_eca_bridge, langchain, etc.

#### Shared Packages
- **native-ai**: Core AI framework
- **secure_project**: Security library
- **reelcode**: AI coding standards

## Shared Utilities

### Migration Status

| Project | Status | Components | Notes |
|---------|--------|------------|-------|
| bfapi |  Complete | Logger, Error Handling, HTTP Client, Circuit Breaker, Retry | Full migration |
| bfllm |  Complete | Logger, Error Handling, HTTP Client | Core utilities migrated |
| llm-mcp |  Complete | Logger, Error Handling, Pooled HTTP Client | Enhanced pooling |
| bfrfp |  Complete | Logger, Error Handling, HTTP Client | Backward compatible |
| llm-gateway-sdk | 🔄 In Progress | Retry Logic, Error Compatibility | Implementation ongoing |
| llm-ui | ⏳ Pending | - | Not started |
| bfcicomponents | ⏳ Pending | - | Not started |
| bfdocs | ⏳ Pending | - | Not started |

### Shared Components

```typescript
// Import from shared utilities
import { 
  LLM PlatformLogger,
  HttpClient,
  createError,
  ERROR_CODES 
} from '@bluefly/cli/shared';
```

Available components:
- **config**: Configuration management
- **errors**: Error handling
- **http**: HTTP client
- **logger**: Logging system
- **observability**: Monitoring
- **services**: Common services
- **utils**: Utility functions

## Development Standards

### Code Style
- TypeScript/JavaScript: ESLint
- PHP: Drupal standards (PSR-2, PSR-4)
- 90%+ test coverage
- TDD methodology

### Architecture
- API gateway communication
- Modern component architecture
- MCP bridge for Drupal
- Multi-layer security

### Common Commands

```bash
# Node.js
npm run build      # Build
npm run test       # Test
npm run lint       # Lint
npm run start      # Dev server

# Drupal
composer install    # Dependencies
composer test       # Tests
composer stan       # Static analysis
```

## Cross-Project Development

1. Core service (bfllm)
2. API gateway (bfapi)
3. Client library (llm-gateway-sdk)
4. UI components (llm-ui)
5. Drupal modules
6. Documentation (bfdocs)
7. CI/CD (bfcicomponents)

## Security Framework

1. **secure_project**: Node.js security
2. **secure_drupal**: Drupal security
3. **JWT Authentication**
4. **API Gateway Security**
5. **Telemetry & Monitoring**

## File Management

### Preservation Policy
1. Move to `__DELETE_LATER`
2. Preserve structure
3. Add date suffix
4. Document in DELETE_LOG.md

### Task Management
- Use TodoWrite
- Track completion
- Update documentation

## Security Guidelines

- No sensitive data in commits
- Authenticate all endpoints
- Least privilege principle
- Input validation
- Use security modules

## AI Assistant Configuration

### Core Understanding
1. Microservice Architecture
2. Polyglot Environment
3. Security Standards
4. Test-Driven Development
5. Documentation Requirements

### Reelcode Standards
1. `reelcode generate:ai-config`
2. `.reelcode` directory standards
3. CLAUDE.md templates

## Logging and Monitoring

### TypeScript/JavaScript
```typescript
import { logger } from '@bluefly/shared';

// Info logging
logger.info('Operation completed', { 
  component: 'llm-mcp',
  operation: 'modelLoad',
  duration: 450,
  success: true 
});

// Error logging
logger.error('Operation failed', {
  component: 'bfapi',
  operation: 'inference',
  errorCode: 'MODEL_UNAVAILABLE',
  details: error.message
});
```

### PHP/Drupal
```php
// Info logging
\Drupal::logger('module_name')->info('Operation completed: @operation', [
  '@operation' => 'entity_creation',
  '@duration' => 450,
  '@success' => TRUE
]);

// Error logging
\Drupal::logger('module_name')->error('Operation failed: @error', [
  '@error' => $e->getMessage(),
  '@code' => $e->getCode(),
  '@trace' => $e->getTraceAsString()
]);
```

## Related Documentation

- [API Documentation](../api/README)
- [Architecture Guide](../architecture/README)
- [Development Guide](../development/README)
- [Testing Guide](../testing/README)
- [Security Guide](../operations/security)
- [Monitoring Guide](../operations/monitoring)

==> llm-docs-1.0.1.tgz: package/docs/development/claude-integration.md <==
---
id: development-claude-integration
---
# Claude Integration Guide

<!-- title: Claude Integration Guide -->
<!-- description: Guide for integrating Claude AI with the Bluefly Platform ecosystem -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide provides comprehensive documentation for integrating Claude AI with the Bluefly Platform ecosystem. It covers architecture, development standards, security considerations, and best practices for working with Claude in our multi-project environment.

## Ecosystem Architecture

### Core Projects

The Bluefly AI Platform consists of these interconnected projects:

1. **bfapi**: API Gateway service
2. **bfmcp**: Model Control Plane
3. **bfllm**: Core LLM services
4. **bfrfp**: Content generation
5. **bfui**: Frontend components
6. **bfapiclient**: Client library
7. **bfdocs**: Documentation hub
8. **bfcli**: CLI for platform management
9. **bfcicomponents**: CI/CD components
10. **llm_platform_recipe**: Drupal integration

### Integration Components

#### Drupal Modules
- **drupal_native_ai**: Core AI capabilities
- **llm**: Platform integration
- **ai_swarm_intelligence**: Swarm capabilities
- **secure_drupal**: Security framework
- **Integration modules**: field_eca_bridge, langchain, etc.

#### Shared Packages
- **native-ai**: Core AI framework
- **secure_project**: Security library
- **reelcode**: AI coding standards

## Shared Utilities

### Migration Status

| Project | Status | Components | Notes |
|---------|--------|------------|-------|
| bfapi |  Complete | Logger, Error Handling, HTTP Client, Circuit Breaker, Retry | Full migration |
| bfllm |  Complete | Logger, Error Handling, HTTP Client | Core utilities migrated |
| bfmcp |  Complete | Logger, Error Handling, Pooled HTTP Client | Enhanced pooling |
| bfrfp |  Complete | Logger, Error Handling, HTTP Client | Backward compatible |
| bfapiclient | 🔄 In Progress | Retry Logic, Error Compatibility | Implementation ongoing |
| bfui | ⏳ Pending | - | Not started |
| bfcicomponents | ⏳ Pending | - | Not started |
| bfdocs | ⏳ Pending | - | Not started |

### Shared Components

```typescript
// Import from shared utilities
import { 
  BlueflyLogger,
  HttpClient,
  createError,
  ERROR_CODES 
} from '@bluefly/cli/shared';
```

Available components:
- **config**: Configuration management
- **errors**: Error handling
- **http**: HTTP client
- **logger**: Logging system
- **observability**: Monitoring
- **services**: Common services
- **utils**: Utility functions

## Development Standards

### Code Style
- TypeScript/JavaScript: ESLint
- PHP: Drupal standards (PSR-2, PSR-4)
- 90%+ test coverage
- TDD methodology

### Architecture
- API gateway communication
- Modern component architecture
- MCP bridge for Drupal
- Multi-layer security

### Common Commands

```bash
# Node.js
npm run build      # Build
npm run test       # Test
npm run lint       # Lint
npm run start      # Dev server

# Drupal
composer install    # Dependencies
composer test       # Tests
composer stan       # Static analysis
```

## Cross-Project Development

1. Core service (bfllm)
2. API gateway (bfapi)
3. Client library (bfapiclient)
4. UI components (bfui)
5. Drupal modules
6. Documentation (bfdocs)
7. CI/CD (bfcicomponents)

## Security Framework

1. **secure_project**: Node.js security
2. **secure_drupal**: Drupal security
3. **JWT Authentication**
4. **API Gateway Security**
5. **Telemetry & Monitoring**

## File Management

### Preservation Policy
1. Move to `__DELETE_LATER`
2. Preserve structure
3. Add date suffix
4. Document in DELETE_LOG.md

### Task Management
- Use TodoWrite
- Track completion
- Update documentation

## Security Guidelines

- No sensitive data in commits
- Authenticate all endpoints
- Least privilege principle
- Input validation
- Use security modules

## AI Assistant Configuration

### Core Understanding
1. Microservice Architecture
2. Polyglot Environment
3. Security Standards
4. Test-Driven Development
5. Documentation Requirements

### Reelcode Standards
1. `reelcode generate:ai-config`
2. `.reelcode` directory standards
3. CLAUDE.md templates

## Logging and Monitoring

### TypeScript/JavaScript
```typescript
import { logger } from '@bluefly/shared';

// Info logging
logger.info('Operation completed', { 
  component: 'bfmcp',
  operation: 'modelLoad',
  duration: 450,
  success: true 
});

// Error logging
logger.error('Operation failed', {
  component: 'bfapi',
  operation: 'inference',
  errorCode: 'MODEL_UNAVAILABLE',
  details: error.message
});
```

### PHP/Drupal
```php
// Info logging
\Drupal::logger('module_name')->info('Operation completed: @operation', [
  '@operation' => 'entity_creation',
  '@duration' => 450,
  '@success' => TRUE
]);

// Error logging
\Drupal::logger('module_name')->error('Operation failed: @error', [
  '@error' => $e->getMessage(),
  '@code' => $e->getCode(),
  '@trace' => $e->getTraceAsString()
]);
```

## Related Documentation

- [API Documentation](../api/README)
- [Architecture Guide](../architecture/README)
- [Development Guide](../development/README)
- [Testing Guide](../testing/README)
- [Security Guide](../operations/security)
- [Monitoring Guide](../operations/monitoring)
